@@ -21,7 +21,18 @@ def get_property(object_type, property_name):
 
 def update_property(object_type, property_name, data):
   post_url = f"{BASE_URL}crm/v3/properties/{object_type}/{property_name}"
-  result = patch(post_url, HEADERS, payload=data)
+  acceptable_keys = [
+      'groupName',
+      'hidden',
+      'displayOrder',
+      'options',
+      'label',
+      'type',
+      'fieldType',
+      'formField'
+  ]
+  data = {k: v for k, v in data.items() if k in acceptable_keys}
+  result = patch(post_url, HEADERS, payload=json.dumps(data))
   if not Utils.is_success(result['status_code']):
     raise Exception(f"Failed to update property. Result: {result}")
   return result
