@@ -9,6 +9,9 @@ def create_item(item):
   authenticate()
   post_url = f"{BASE_URL}"
   result = post(post_url, HEADERS, json.dumps(item))
+  if Utils.is_unauthorized(result['status_code']):
+    authenticate(force=True)
+    result = post(post_url, HEADERS, json.dumps(item))
   if not Utils.is_success(result['status_code']):
     raise Exception(f"Failed to create item. Result: {result}")
   return result
@@ -18,6 +21,9 @@ def update_item(item_id, item):
   authenticate()
   post_url = f"{BASE_URL}/{item_id}"
   result = put(post_url, HEADERS, json.dumps(item))
+  if Utils.is_unauthorized(result['status_code']):
+    authenticate(force=True)
+    result = put(post_url, HEADERS, json.dumps(item))
   if not Utils.is_success(result['status_code']):
     raise Exception(f"Failed to update item. Result: {result}")
   return result
@@ -27,6 +33,9 @@ def get_item(item_id):
   authenticate()
   post_url = f"{BASE_URL}/{item_id}"
   result = get(post_url, HEADERS)
+  if Utils.is_unauthorized(result['status_code']):
+    authenticate(force=True)
+    result = get(post_url, HEADERS)
   if not Utils.is_success(result['status_code']):
     raise Exception(f"Failed to retrieve item. Result: {result}")
   return result
@@ -59,6 +68,9 @@ def search_items(name=None,
   for name, value in kwargs.items():
     post_url = f"{post_url}&{name}={value}"
   result = get(post_url, HEADERS)
+  if Utils.is_unauthorized(result['status_code']):
+    authenticate(force=True)
+    result = get(post_url, HEADERS)
   if not Utils.is_success(result['status_code']):
     raise Exception(f"Failed to retrieve items. Result: {result}")
   return result
